'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var ExtractTextPlugin = _interopDefault(require('extract-text-webpack-plugin'));

var HandleCSSLoader = function HandleCSSLoader(ref) {
  if ( ref === void 0 ) ref = {};
  var fallbackLoader = ref.fallbackLoader; if ( fallbackLoader === void 0 ) fallbackLoader = 'style-loader';
  var cssLoader = ref.cssLoader; if ( cssLoader === void 0 ) cssLoader = 'css-loader';
  var postcss = ref.postcss;
  var sourceMap = ref.sourceMap;
  var extract = ref.extract;
  var minimize = ref.minimize;

  this.fallbackLoader = fallbackLoader;
  this.cssLoader = cssLoader;
  this.postcssOptions = postcss;
  this.sourceMap = sourceMap;
  this.extract = extract;
  this.minimize = minimize;
};

HandleCSSLoader.prototype.getLoader = function getLoader (test, loader, options) {
  var use = [{
    loader: this.cssLoader,
    options: {
      autoprefixer: false,
      sourceMap: this.sourceMap,
      minimize: this.minimize
    }
  }];
  if (loader !== 'postcss-loader' && this.postcssOptions !== false) {
    use.push({
      loader: 'postcss-loader',
      options: Object.assign({}, this.postcssOptions,
        {sourceMap: this.sourceMap})
    });
  }
  if (loader && loader !== 'css-loader') {
    use.push({
      loader: loader,
      options: Object.assign({}, options,
        {sourceMap: this.sourceMap})
    });
  }
  return {
    test: test,
    use: this.extract ? ExtractTextPlugin.extract({
      use: use,
      fallback: this.fallbackLoader
    }) : use
  }
};

HandleCSSLoader.prototype.css = function css () {
  return this.getLoader(/\.css$/, 'css-loader')
};

HandleCSSLoader.prototype.sass = function sass () {
  return this.getLoader(/\.sass$/, 'sass-loader', {
    indentedSyntax: true
  })
};

HandleCSSLoader.prototype.scss = function scss () {
  return this.getLoader(/\.scss$/, 'sass-loader')
};

HandleCSSLoader.prototype.less = function less () {
  return this.getLoader(/\.less$/, 'less-loader')
};

HandleCSSLoader.prototype.stylus = function stylus () {
  return this.getLoader(/\.(stylus|styl)$/, 'stylue-loader')
};

HandleCSSLoader.prototype.styl = function styl () {
  return this.getLoader(/\.(stylus|styl)$/, 'stylue-loader')
};

module.exports = HandleCSSLoader;
